MLKEM1024 class

Constructors

MLKEM1024()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decapsulate(Uint8List ciphertext, Uint8List secretKey) Uint8List
inherited
encapsulate(Uint8List publicKey, {Uint8List? coins}) EncapsulationResult
inherited
generateKeyPair({Uint8List? coins}) KeyPair
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited